"""Example classes for message responses."""
from wexample_prompt.example.response.messages.debug_example import DebugExample
from wexample_prompt.example.response.messages.info_example import InfoExample
from wexample_prompt.example.response.messages.log_example import LogExample
from wexample_prompt.example.response.messages.success_example import SuccessExample

__all__ = [
    'DebugExample',
    'InfoExample',
    'LogExample',
    'SuccessExample',
]
